@@ -1,11 +1,12 @@
 """Test the firmware update helper."""
 from unittest.mock import patch
 
-from zwave_js_server.firmware import begin_firmware_update
+from zwave_js_server.firmware import update_firmware
+from zwave_js_server.model.firmware import FirmwareUpdateData
 
 
-async def test_begin_firmware_update_guess_format(url, client_session, multisensor_6):
-    """Test begin_firmware_update with guessed format."""
+async def test_update_firmware_guess_format(url, client_session, multisensor_6):
+    """Test update_firmware with guessed format."""
     with patch("zwave_js_server.firmware.Client.connect") as connect_mock, patch(
         "zwave_js_server.firmware.Client.initialize"
     ) as initialize_mock, patch(
@@ -14,26 +15,33 @@ async def test_begin_firmware_update_guess_format(url, client_session, multisens
         "zwave_js_server.firmware.Client.disconnect"
     ) as disconnect_mock:
         node = multisensor_6
-        await begin_firmware_update(url, node, "test", bytes(10), client_session)
+        cmd_mock.return_value = {"success": True}
+        assert await update_firmware(
+            url, node, [FirmwareUpdateData("test", bytes(10))], client_session
+        )
 
         connect_mock.assert_called_once()
         initialize_mock.assert_called_once()
         cmd_mock.assert_called_once_with(
             {
-                "command": "node.begin_firmware_update",
+                "command": "node.update_firmware",
                 "nodeId": node.node_id,
-                "firmwareFilename": "test",
-                "firmwareFile": "AAAAAAAAAAAAAA==",
+                "updates": [
+                    {
+                        "filename": "test",
+                        "file": "AAAAAAAAAAAAAA==",
+                    }
+                ],
             },
-            require_schema=18,
+            require_schema=24,
         )
         disconnect_mock.assert_called_once()
 
 
-async def test_begin_firmware_update_known_format_and_target(
+async def test_update_firmware_known_format_and_target(
     url, client_session, multisensor_6
 ):
-    """Test begin_firmware_update with known format."""
+    """Test update_firmware with known format."""
     with patch("zwave_js_server.firmware.Client.connect") as connect_mock, patch(
         "zwave_js_server.firmware.Client.initialize"
     ) as initialize_mock, patch(
@@ -42,27 +50,28 @@ async def test_begin_firmware_update_known_format_and_target(
         "zwave_js_server.firmware.Client.disconnect"
     ) as disconnect_mock:
         node = multisensor_6
-        await begin_firmware_update(
+        cmd_mock.return_value = {"success": True}
+        assert await update_firmware(
             url=url,
             node=node,
-            filename="test",
-            file=bytes(10),
+            updates=[FirmwareUpdateData("test", bytes(10), "test")],
             session=client_session,
-            file_format="test",
-            target=0,
         )
 
         connect_mock.assert_called_once()
         initialize_mock.assert_called_once()
         cmd_mock.assert_called_once_with(
             {
-                "command": "node.begin_firmware_update",
+                "command": "node.update_firmware",
                 "nodeId": node.node_id,
-                "firmwareFilename": "test",
-                "firmwareFile": "AAAAAAAAAAAAAA==",
-                "firmwareFileFormat": "test",
-                "target": 0,
+                "updates": [
+                    {
+                        "filename": "test",
+                        "file": "AAAAAAAAAAAAAA==",
+                        "fileFormat": "test",
+                    }
+                ],
             },
-            require_schema=18,
+            require_schema=24,
         )
         disconnect_mock.assert_called_once()
